@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WWW::Netflix::API;
 
-my %vars = do('vars.inc');
+my %vars = do('./vars.inc');
 my $netflix = WWW::Netflix::API->new({
 	consumer_key    => $vars{consumer_key},
 	consumer_secret => $vars{consumer_secret},
@@ -15,6 +15,6 @@ my $netflix = WWW::Netflix::API->new({
 # But note that Netflix only updates the catalog daily.
 # The catalog is ~300MB of POX.
 
-$netflix->REST->Catalog->Titles->Index;
+$netflix->REST->Catalog->Titles->Streaming;
 $netflix->Get();
 
