@@ -17,6 +17,7 @@ my $netflix = WWW::Netflix::API->new({
         %env,
         content_filter => sub { XMLin(@_) },
 });
+my $base_url = $netflix->{base_url};
 
 
 $netflix->REST->Catalog->Titles->Movies('517905');
@@ -30,7 +31,7 @@ print Dumper $netflix->content;
 
 __END__
 
-my $url = 'http://api.netflix.com/catalog/titles/movies/517905?expand=cast,directors';
+my $url = 'http:// . $base_url . '/catalog/titles/movies/517905?expand=cast,directors';
 my ($rest, $submit) = $netflix->rest2sugar($url);
 
 print qq{
@@ -43,6 +44,6 @@ $url
 
 __END__
 
-perl -MWWW::Netflix::API -le 'print for WWW::Netflix::API->new->rest2sugar(shift)' "http://api.netflix.com/catalog/titles/movies/517905?expand=cast,directors"
+perl -MWWW::Netflix::API -le 'print for WWW::Netflix::API->new->rest2sugar(shift)' "http://api-public.netflix.com/catalog/titles/movies/517905?expand=cast,directors"
 
 
